@@ -305,6 +305,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                           pyatspi.ROLE_MENU_ITEM,
                           pyatspi.ROLE_PARAGRAPH,
                           pyatspi.ROLE_SECTION,
+                          pyatspi.ROLE_REDUNDANT_OBJECT,
                           pyatspi.ROLE_UNKNOWN]
         else:
             doNotSpeak = [pyatspi.ROLE_UNKNOWN]
@@ -333,7 +334,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 text = self._script.utilities.queryNonEmptyText(obj)
                 if text and end not in [None, text.characterCount]:
                     return []
-            if role in [pyatspi.ROLE_ENTRY, pyatspi.ROLE_PASSWORD_TEXT]:
+            if role in [pyatspi.ROLE_ENTRY, pyatspi.ROLE_PASSWORD_TEXT, pyatspi.ROLE_SPIN_BUTTON]:
                 result.append(self.getLocalizedRoleName(obj, **args))
             elif obj.parent and not obj.parent.getState().contains(pyatspi.STATE_EDITABLE):
                 if lastKey not in ["Home", "End", "Up", "Down", "Left", "Right", "Page_Up", "Page_Down"]:
